==> google-cloud-tasks-2.1.0.tar.gz: google-cloud-tasks-2.1.0/google/cloud/tasks_v2beta2/types/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .target import (
    PullTarget,
    PullMessage,
    AppEngineHttpTarget,
    AppEngineHttpRequest,
    AppEngineRouting,
)
from .queue import (
    Queue,
    RateLimits,
    RetryConfig,
)
from .task import (
    Task,
    TaskStatus,
    AttemptStatus,
)
from .cloudtasks import (
    ListQueuesRequest,
    ListQueuesResponse,
    GetQueueRequest,
    CreateQueueRequest,
    UpdateQueueRequest,
    DeleteQueueRequest,
    PurgeQueueRequest,
    PauseQueueRequest,
    ResumeQueueRequest,
    ListTasksRequest,
    ListTasksResponse,
    GetTaskRequest,
    CreateTaskRequest,
    DeleteTaskRequest,
    LeaseTasksRequest,
    LeaseTasksResponse,
    AcknowledgeTaskRequest,
    RenewLeaseRequest,
    CancelLeaseRequest,
    RunTaskRequest,
)


__all__ = (
    "PullTarget",
    "PullMessage",
    "AppEngineHttpTarget",
    "AppEngineHttpRequest",
    "AppEngineRouting",
    "Queue",
    "RateLimits",
    "RetryConfig",
    "Task",
    "TaskStatus",
    "AttemptStatus",
    "ListQueuesRequest",
    "ListQueuesResponse",
    "GetQueueRequest",
    "CreateQueueRequest",
    "UpdateQueueRequest",
    "DeleteQueueRequest",
    "PurgeQueueRequest",
    "PauseQueueRequest",
    "ResumeQueueRequest",
    "ListTasksRequest",
    "ListTasksResponse",
    "GetTaskRequest",
    "CreateTaskRequest",
    "DeleteTaskRequest",
    "LeaseTasksRequest",
    "LeaseTasksResponse",
    "AcknowledgeTaskRequest",
    "RenewLeaseRequest",
    "CancelLeaseRequest",
    "RunTaskRequest",
)

==> google-cloud-tasks-2.10.2.tar.gz: google-cloud-tasks-2.10.2/google/cloud/tasks_v2beta2/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .cloudtasks import (
    AcknowledgeTaskRequest,
    CancelLeaseRequest,
    CreateQueueRequest,
    CreateTaskRequest,
    DeleteQueueRequest,
    DeleteTaskRequest,
    GetQueueRequest,
    GetTaskRequest,
    LeaseTasksRequest,
    LeaseTasksResponse,
    ListQueuesRequest,
    ListQueuesResponse,
    ListTasksRequest,
    ListTasksResponse,
    PauseQueueRequest,
    PurgeQueueRequest,
    RenewLeaseRequest,
    ResumeQueueRequest,
    RunTaskRequest,
    UpdateQueueRequest,
)
from .queue import Queue, QueueStats, RateLimits, RetryConfig
from .target import (
    AppEngineHttpRequest,
    AppEngineHttpTarget,
    AppEngineRouting,
    HttpMethod,
    PullMessage,
    PullTarget,
)
from .task import AttemptStatus, Task, TaskStatus

__all__ = (
    "AcknowledgeTaskRequest",
    "CancelLeaseRequest",
    "CreateQueueRequest",
    "CreateTaskRequest",
    "DeleteQueueRequest",
    "DeleteTaskRequest",
    "GetQueueRequest",
    "GetTaskRequest",
    "LeaseTasksRequest",
    "LeaseTasksResponse",
    "ListQueuesRequest",
    "ListQueuesResponse",
    "ListTasksRequest",
    "ListTasksResponse",
    "PauseQueueRequest",
    "PurgeQueueRequest",
    "RenewLeaseRequest",
    "ResumeQueueRequest",
    "RunTaskRequest",
    "UpdateQueueRequest",
    "Queue",
    "QueueStats",
    "RateLimits",
    "RetryConfig",
    "AppEngineHttpRequest",
    "AppEngineHttpTarget",
    "AppEngineRouting",
    "PullMessage",
    "PullTarget",
    "HttpMethod",
    "AttemptStatus",
    "Task",
    "TaskStatus",
)
